// This work is licensed under the Creative Commons Attribution 3.0 Unported License.
// To view a copy of this license, visit http://creativecommons.org/licenses/by/3.0/
// or send a letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View,
// California, 94041, USA.
//
// Persistence Of Vision Ray Tracer ('POV-Ray') sample file. Branch --> povr.
//
// Various fog examples: fog.pov.
//
#version unofficial 3.8; // povr
global_settings {
    assumed_gamma 1
    number_of_waves 10
}
#declare MidnightBlue1 = srgb <0,0.27451,0.54902>;
#declare SkySphere00 = sky_sphere {
    pigment { color MidnightBlue1 }
}
#declare Camera00 = camera {
    perspective
    location <4,3,-8.001>
    sky y
    angle 65
    right x*(image_width/image_height)
    look_at <-1,1.5,0>
}
#declare Grey90 = srgb <0.9,0.9,0.9>;
#declare Light00 = light_source {
    <30,50,-50>, Grey90
}
#declare MidnightBlue = srgb <0.09804,0.09804,0.43922>;
#declare Light01 = light_source {
    <-30,50,-50>, MidnightBlue
}
#declare Red = srgb <1,0,0>;
#declare CylinderX = cylinder {
    -1*x, 1*x, 0.01
    pigment { color Red }
}
#declare Green = srgb <0,1,0>;
#declare CylinderY = cylinder {
    -1*y, 1*y, 0.01
    pigment { color Green }
}
#declare Blue = srgb <0,0,1>;
#declare CylinderZ = cylinder {
    -1*z, 1*z, 0.01
    pigment { color Blue }
}
#declare PlaneWater = plane {
    y, 0
}
#declare PigmentWater = pigment {
    color MidnightBlue1
}
#declare NormalWater = normal {
    ripples frequency 7
    scale 1.5
}
#declare Grey15 = srgb <0.15,0.15,0.15>;
#declare FinishWater = finish {
    ambient Grey15
    reflection { Grey15
    }
}
#declare TextureWater = texture {
    pigment { PigmentWater }
    finish { FinishWater }
    normal { NormalWater }
}
#declare ObjWater = object {
    PlaneWater
    texture { TextureWater }
}
#declare Grey70 = srgb <0.7,0.7,0.7>;
#declare Wheat = srgb <0.96078,0.87059,0.70196>;
#declare PigmentBrick = pigment {
    brick
    pigment { Grey70 }
    pigment { Wheat }
}
#declare NormalBrick = normal {
    brick  0.75
}
#declare Grey05 = srgb <0.05,0.05,0.05>;
#declare FinishBrick = finish {
    ambient Grey05
}
#declare TextureBrick = texture {
    pigment { PigmentBrick }
    finish { FinishBrick }
    normal { NormalBrick }
    scale <0.1,0.1,0.05>
    translate <0.25,0.30,0.25>
}
#include "Bridge.inc"
// Object Bridge defined in Bridge.inc
#declare BridgeScale = object {
    Bridge
    scale <5.25,4,1>
}
#declare ObjBridge = object {
    BridgeScale
    texture { TextureBrick }
    rotate y*90
    translate <-1,0,25>
}
// Object Building defined in Bridge.inc
#declare TextureBrick2x = texture {
    TextureBrick
    scale 2.0
}
#declare ObjBuilding = object {
    Building
    texture { TextureBrick2x }
}
#declare Fog01 = fog {
    type 1
    distance 9.5
    color Grey70
}
#declare Fog01_wTurb = fog {
    Fog01
    it_scale <1.6,0.16,1.6>
    it_depth 2.1
    it_octaves 5
    it_omega 0.35
    it_lambda 1.25
}
#declare Fog01_neg_it_depth = fog {
    Fog01_wTurb
    it_depth -2.1
}
#declare Fog01_blend_gamma = fog {
    Fog01_wTurb
    blend_gamma 2
}
#declare Fog01_inverse = fog {
    Fog01_wTurb
    inverse
}
#declare Fog01_range = fog {
    Fog01_wTurb
    range 7, 20
    blend_gamma 2
}
#declare Fog03_rotate = fog {
    Fog01_inverse
    type 3
    rotate z*45
}
#declare Fog02 = fog {
    type 2
    distance 100
    altitude 0.23
    offset 0
    it_scale <0.18,0.18,0.18>
    it_depth 0.6
    it_octaves 6
    it_omega 0.47
    it_lambda 1.55
    color Grey70
}
#declare ColorForRange = srgbft <1,1,0.01,0,0.1>;
#declare Fog04 = fog {
    type 4
    range 0, 100
    color ColorForRange
}
#declare Fog05 = fog {
    type 5
    range 9.5, 10.5
    blend_gamma 5
    color ColorForRange
}

//--- scene ---
    sky_sphere { SkySphere00 }
    camera { Camera00 }
    light_source { Light00 }
    light_source { Light01 }
//  object { CylinderX }
//  object { CylinderY }
//  object { CylinderZ }
//  fog { Fog01 }
//  fog { Fog01_wTurb }
//  fog { Fog01_blend_gamma }
//  fog { Fog01_inverse }
    fog { Fog01_range }
//  fog { Fog01_neg_it_depth }
//  fog { Fog03_rotate }
//  fog { Fog02 }
//  fog { Fog04 }
//  fog { Fog05 }
    object { ObjWater }
    object { ObjBridge }
    object { ObjBuilding }
